@@ -10,7 +10,7 @@
 #include <sys/utsname.h>
 #include <unistd.h>
 
-#define VERSION "3.0.2"
+#define VERSION "3.1.1"
 
 #define ET_EXEC 2
 #define ET_DYN 3
@@ -84,11 +84,20 @@
 
 // Libraries we do not show by default -- this reduces the verbosity quite a
 // bit.
-char const *exclude_list[] = {
-    "libc.so",     "libpthread.so",       "libm.so",
-    "libgcc_s.so", "libstdc++.so",        "ld-linux-x86-64.so",
-    "libdl.so",    "libc.musl-x86_64.so", "ld-linux.so",
-    "ld64.so",     "ld-linux-aarch64.so"};
+char const *exclude_list[] = {"ld-linux-aarch64.so",
+                              "ld-linux-armhf.so",
+                              "ld-linux-x86-64.so",
+                              "ld-linux.so",
+                              "ld64.so",
+                              "libc.musl-aarch64.so",
+                              "libc.musl-armhf.so",
+                              "libc.musl-i386.so",
+                              "libc.musl-x86_64.so",
+                              "libc.so",
+                              "libdl.so",
+                              "libgcc_s.so",
+                              "libm.so",
+                              "libstdc++.so"};
 
 struct header_64_t {
     uint16_t e_type;
@@ -201,6 +210,7 @@ struct libtree_state_t {
     int path;
     int color;
     char *ld_conf_file;
+    unsigned long max_depth;
 
     struct string_table_t string_table;
     struct visited_file_array_t visited;
@@ -1187,19 +1197,27 @@ static int recurse(char *current_file, size_t depth, struct libtree_state_t *s,
 
     // No need to recurse deeper when we aren't in very verbose mode.
     int should_recurse =
-        depth < MAX_RECURSION_DEPTH &&
+        depth < s->max_depth &&
         ((!seen_before && !in_exclude_list) ||
          (!seen_before && in_exclude_list && s->verbosity >= 2) ||
-         s->verbosity == 3);
+         s->verbosity >= 3);
 
     // Just print the library and return
     if (!should_recurse) {
-        char *print_name = soname != MAX_OFFSET_T && !s->path
-                               ? s->string_table.arr + soname_buf_offset
-                               : current_file;
-        char *bold_color = in_exclude_list ? REGULAR_MAGENTA : REGULAR_BLUE;
-        char *regular_color = in_exclude_list ? REGULAR_MAGENTA : REGULAR_BLUE;
-        print_line(depth, print_name, bold_color, regular_color, 0, reason, s);
+        char *print_name = soname == MAX_OFFSET_T || s->path
+                               ? current_file
+                               : (s->string_table.arr + soname_buf_offset);
+
+        char *bold_color = in_exclude_list
+                               ? REGULAR_MAGENTA
+                               : seen_before ? REGULAR_BLUE : BOLD_CYAN;
+        char *regular_color = in_exclude_list
+                                  ? REGULAR_MAGENTA
+                                  : seen_before ? REGULAR_BLUE : REGULAR_CYAN;
+
+        int highlight = !seen_before && !in_exclude_list;
+        print_line(depth, print_name, bold_color, regular_color, highlight,
+                   reason, s);
 
         s->string_table.n = old_buf_size;
         fclose(fptr);
@@ -1638,6 +1656,7 @@ int main(int argc, char **argv) {
     s.color = getenv("NO_COLOR") == NULL && isatty(STDOUT_FILENO);
     s.verbosity = 0;
     s.path = 0;
+    s.max_depth = MAX_RECURSION_DEPTH;
 
     // We want to end up with an array of file names
     // in argv[1] up to argv[positional-1].
@@ -1704,6 +1723,17 @@ int main(int argc, char **argv) {
                     return 1;
                 }
                 s.ld_conf_file = argv[++i];
+            } else if (strcmp(arg, "max-depth") == 0) {
+                // Require a value
+                if (i + 1 == argc) {
+                    fputs("Expected value after `--max-depth`\n", stderr);
+                    return 1;
+                }
+                // Limit it by MAX_RECURSION_DEPTH.
+                char *ptr;
+                s.max_depth = strtoul(argv[++i], &ptr, 10);
+                if (s.max_depth > MAX_RECURSION_DEPTH)
+                    s.max_depth = MAX_RECURSION_DEPTH;
             } else {
                 fputs("Unrecognized flag `--", stderr);
                 fputs(arg, stderr);
@@ -1758,6 +1788,7 @@ int main(int argc, char **argv) {
               "  --ldconf <path>  Config file for extra search paths [", stdout);
         fputs(s.ld_conf_file, stdout);
         fputs("]\n"
+              "  --max-depth <n>  Limit library traversal to at most n levels of depth\n"
               "\n"
               "* For brevity, the following libraries are not shown by default:\n"
               "  ",
